PrettyQrCustomShape class

A class for creates custom QR Code shape.

Inheritance
Annotations
  • @sealed
  • @experimental

Constructors

PrettyQrCustomShape(PrettyQrShape shape, {PrettyQrShape? finderPattern, PrettyQrShape? timingPatterns, PrettyQrShape? alignmentPatterns})
Creates a custom QR Code shape.
const

Properties

alignmentPatterns PrettyQrShape?
final
finderPattern PrettyQrShape?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape PrettyQrShape
final
timingPatterns PrettyQrShape?
final

Methods

getBounds(PrettyQrPaintingContext context) Rect
Returns a bounds of the QR code symbol painted by paint, as an axis-aligned Rect.
inherited
lerpFrom(PrettyQrShape? a, double t) PrettyQrCustomShape?
Linearly interpolates from another PrettyQrShape (which may be of a different class) to this.
override
lerpTo(PrettyQrShape? b, double t) PrettyQrCustomShape?
Linearly interpolates from this to another PrettyQrShape (which may be of a different class).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PrettyQrPaintingContext context) → void
Paints the QR matrix on the canvas of the given painting context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override